@@ -101,6 +101,25 @@ void disableDrKonqi()
 // that would enable drkonqi
 Q_CONSTRUCTOR_FUNCTION(disableDrKonqi)
 
+// Verify that a package or its fallback is using the right API
+bool verifyPackageApi(const KPackage::Package &package)
+{
+    if (package.metadata().value("X-Plasma-APIVersion", QStringLiteral("1")).toInt() >= 2) {
+        return true;
+    }
+
+    if (!package.filePath("lockscreenmainscript").contains(package.path())) {
+        // The current package does not contain the lock screen and we are
+        // using the fallback package. So check to see if that package has
+        // the right version instead.
+        if (package.fallbackPackage().metadata().value("X-Plasma-APIVersion", QStringLiteral("1")).toInt() >= 2) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
 class FocusOutEventFilter : public QAbstractNativeEventFilter
 {
 public:
@@ -130,23 +149,13 @@ UnlockApp::UnlockApp(int &argc, char **argv)
     , m_testing(false)
     , m_ignoreRequests(false)
     , m_immediateLock(false)
+    , m_authenticator(new PamAuthenticator("kde", KUser().loginName(), this))
     , m_graceTime(0)
     , m_noLock(false)
     , m_defaultToSwitchUser(false)
     , m_wallpaperIntegration(new WallpaperIntegration(this))
     , m_lnfIntegration(new LnFIntegration(this))
 {
-    m_authenticator = new PamAuthenticator("kde", KUser().loginName(), this);
-    // It's a queued connection to give the QML part time to eventually execute code connected to Authenticator::succeeded if any
-    connect(
-        m_authenticator,
-        &PamAuthenticator::succeeded,
-        this,
-        []() {
-            qApp->quit();
-        },
-        Qt::QueuedConnection);
-
     initialize();
 
     if (QX11Info::isPlatformX11()) {
@@ -196,10 +205,9 @@ void UnlockApp::initialize()
     if (!KScreenSaverSettingsBase::theme().isEmpty()) {
         package.setPath(KScreenSaverSettingsBase::theme());
     }
-    QString plasmaApiVersion = package.metadata().value("X-Plasma-APIVersion", QStringLiteral("1"));
-    if (plasmaApiVersion.toInt() <= 1) {
+    if (!verifyPackageApi(package)) {
         qCWarning(KSCREENLOCKER_GREET) << "Lockscreen QML outdated, falling back to default";
-        package.setPath(QString());
+        package.setPath(QStringLiteral("org.kde.breeze.desktop"));
     }
 
     m_mainQmlPath = package.fileUrl("lockscreenmainscript");
@@ -339,6 +347,13 @@ KQuickAddons::QuickViewSharedEngine *UnlockApp::createViewForScreen(QScreen *scr
 
     // engine stuff
     QQmlContext *context = view->engine()->rootContext();
+    connect(view->engine(), &QQmlEngine::quit, this, [this]() {
+        if (m_authenticator->isUnlocked()) {
+            QCoreApplication::quit();
+        } else {
+            qCWarning(KSCREENLOCKER_GREET) << "Greeter tried to quit without being unlocked";
+        }
+    });
 
     context->setContextProperty(QStringLiteral("kscreenlocker_userName"), m_userName);
     context->setContextProperty(QStringLiteral("kscreenlocker_userImage"), m_userImage);
