@@ -20,15 +20,15 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 #include "kcm.h"
+#include "appearancesettings.h"
+#include "kscreenlockerdata.h"
+#include "lnf_integration.h"
 #include "screenlocker_interface.h"
 #include "wallpaper_integration.h"
-#include "lnf_integration.h"
-#include "kscreenlockerdata.h"
-#include "appearancesettings.h"
 
 #include <KAboutData>
 #include <KConfigLoader>
-#include <KDeclarative/ConfigPropertyMap>
+#include <KConfigPropertyMap>
 #include <KGlobalAccel>
 #include <KLocalizedString>
 #include <KPluginFactory>
@@ -37,27 +37,30 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QVector>
 
-K_PLUGIN_FACTORY_WITH_JSON(ScreenLockerKcmFactory, "screenlocker.json", registerPlugin<ScreenLockerKcm>(); registerPlugin<KScreenLockerData>();)
+K_PLUGIN_FACTORY_WITH_JSON(ScreenLockerKcmFactory, "kcm_screenlocker.json", registerPlugin<ScreenLockerKcm>(); registerPlugin<KScreenLockerData>();)
 
-ScreenLockerKcm::ScreenLockerKcm(QObject *parent, const QVariantList &args)
-    : KQuickAddons::ManagedConfigModule(parent, args)
+ScreenLockerKcm::ScreenLockerKcm(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : KQuickAddons::ManagedConfigModule(parent, data, args)
     , m_appearanceSettings(new AppearanceSettings(this))
 {
     registerSettings(&KScreenSaverSettings::getInstance());
 
-    constexpr const char* url = "org.kde.private.kcms.screenlocker";
+    constexpr const char *url = "org.kde.private.kcms.screenlocker";
     qRegisterMetaType<QVector<WallpaperInfo>>("QVector<WallpaperInfo>");
     qmlRegisterAnonymousType<KScreenSaverSettings>(url, 1);
     qmlRegisterAnonymousType<WallpaperInfo>(url, 1);
     qmlRegisterAnonymousType<ScreenLocker::WallpaperIntegration>(url, 1);
-    qmlRegisterAnonymousType<KDeclarative::ConfigPropertyMap>(url, 1);
+    qmlRegisterAnonymousType<KConfigPropertyMap>(url, 1);
     qmlProtectModule(url, 1);
-    KAboutData *about = new KAboutData(QStringLiteral("kcm_screenlocker"), i18n("Screen Locking"),
-                                       QStringLiteral("1.0"), QString(), KAboutLicense::GPL);
-    about->addAuthor(i18n("Martin Gräßlin"), QString(), QStringLiteral("mgraesslin@kde.org"));
-    about->addAuthor(i18n("Kevin Ottens"), QString(), QStringLiteral("kevin.ottens@enioka.com"));
-    setAboutData(about);
-    connect(&KScreenSaverSettings::getInstance(), &KScreenSaverSettings::wallpaperPluginIdChanged, m_appearanceSettings, &AppearanceSettings::loadWallpaperConfig);
+
+    // Our modules will be checking the Plasmoid attached object when running from Plasma, let it load the module
+    const char *uri = "org.kde.plasma.plasmoid";
+    qmlRegisterUncreatableType<QObject>(uri, 2, 0, "PlasmoidPlaceholder", QStringLiteral("Do not create objects of type Plasmoid"));
+
+    connect(&KScreenSaverSettings::getInstance(),
+            &KScreenSaverSettings::wallpaperPluginIdChanged,
+            m_appearanceSettings,
+            &AppearanceSettings::loadWallpaperConfig);
     connect(m_appearanceSettings, &AppearanceSettings::currentWallpaperChanged, this, &ScreenLockerKcm::currentWallpaperChanged);
 }
 
@@ -75,9 +78,7 @@ void ScreenLockerKcm::save()
     m_appearanceSettings->save();
 
     // reconfigure through DBus
-    OrgKdeScreensaverInterface interface(QStringLiteral("org.kde.screensaver"),
-                                         QStringLiteral("/ScreenSaver"),
-                                         QDBusConnection::sessionBus());
+    OrgKdeScreensaverInterface interface(QStringLiteral("org.kde.screensaver"), QStringLiteral("/ScreenSaver"), QDBusConnection::sessionBus());
     if (interface.isValid()) {
         interface.configure();
     }
@@ -95,7 +96,7 @@ void ScreenLockerKcm::defaults()
 void ScreenLockerKcm::updateState()
 {
     settingsChanged();
-    emit isDefaultsAppearanceChanged();
+    Q_EMIT isDefaultsAppearanceChanged();
 }
 
 bool ScreenLockerKcm::isSaveNeeded() const
@@ -108,12 +109,12 @@ bool ScreenLockerKcm::isDefaults() const
     return m_appearanceSettings->isDefaults();
 }
 
-KDeclarative::ConfigPropertyMap * ScreenLockerKcm::wallpaperConfiguration() const
+KConfigPropertyMap *ScreenLockerKcm::wallpaperConfiguration() const
 {
     return m_appearanceSettings->wallpaperConfiguration();
 }
 
-KDeclarative::ConfigPropertyMap * ScreenLockerKcm::lnfConfiguration() const
+KConfigPropertyMap *ScreenLockerKcm::lnfConfiguration() const
 {
     return m_appearanceSettings->lnfConfiguration();
 }
