@@ -24,6 +24,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QCoreApplication>
 #include <QDBusConnectionInterface>
 #include <QDBusServiceWatcher>
+#include <QStandardPaths>
 
 #include <kscreenlocker_logging.h>
 
@@ -42,10 +43,8 @@ const static QString s_propertyInterface = QStringLiteral("org.freedesktop.DBus.
 LogindIntegration::LogindIntegration(const QDBusConnection &connection, QObject *parent)
     : QObject(parent)
     , m_bus(connection)
-    , m_logindServiceWatcher(new QDBusServiceWatcher(s_login1Service,
-                                                     m_bus,
-                                                     QDBusServiceWatcher::WatchForUnregistration | QDBusServiceWatcher::WatchForRegistration,
-                                                     this))
+    , m_logindServiceWatcher(
+          new QDBusServiceWatcher(s_login1Service, m_bus, QDBusServiceWatcher::WatchForUnregistration | QDBusServiceWatcher::WatchForRegistration, this))
     , m_connected(false)
     , m_inhibitFileDescriptor()
     , m_service(nullptr)
@@ -53,14 +52,18 @@ LogindIntegration::LogindIntegration(const QDBusConnection &connection, QObject
     , m_managerInterface(nullptr)
     , m_sessionInterface(nullptr)
 {
+    // if we are inside Kwin's unit tests don't query or manipulate logind
+    // avoid connecting but keep all stubs in place
+    if (QStandardPaths::isTestModeEnabled()) {
+        return;
+    }
+
     connect(m_logindServiceWatcher, &QDBusServiceWatcher::serviceRegistered, this, &LogindIntegration::logindServiceRegistered);
-    connect(m_logindServiceWatcher, &QDBusServiceWatcher::serviceUnregistered, this,
-        [this]() {
-            m_connected = false;
-            m_sessionPath = QString();
-            emit connectedChanged();
-        }
-    );
+    connect(m_logindServiceWatcher, &QDBusServiceWatcher::serviceUnregistered, this, [this]() {
+        m_connected = false;
+        m_sessionPath = QString();
+        Q_EMIT connectedChanged();
+    });
 
     // check whether the logind service is registered
     QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.DBus"),
@@ -69,23 +72,21 @@ LogindIntegration::LogindIntegration(const QDBusConnection &connection, QObject
                                                           QStringLiteral("ListNames"));
     QDBusPendingReply<QStringList> async = m_bus.asyncCall(message);
     QDBusPendingCallWatcher *callWatcher = new QDBusPendingCallWatcher(async, this);
-    connect(callWatcher, &QDBusPendingCallWatcher::finished, this,
-        [this](QDBusPendingCallWatcher *self) {
-            QDBusPendingReply<QStringList> reply = *self;
-            self->deleteLater();
-            if (!reply.isValid()) {
-                return;
-            }
-            if (reply.value().contains(s_login1Service)) {
-                logindServiceRegistered();
-                // Don't register ck if we have logind
-                return;
-            }
-            if (reply.value().contains(s_consolekitService)) {
-                consolekitServiceRegistered();
-            }
+    connect(callWatcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *self) {
+        QDBusPendingReply<QStringList> reply = *self;
+        self->deleteLater();
+        if (!reply.isValid()) {
+            return;
         }
-    );
+        if (reply.value().contains(s_login1Service)) {
+            logindServiceRegistered();
+            // Don't register ck if we have logind
+            return;
+        }
+        if (reply.value().contains(s_consolekitService)) {
+            consolekitServiceRegistered();
+        }
+    });
 }
 
 LogindIntegration::LogindIntegration(QObject *parent)
@@ -98,11 +99,8 @@ LogindIntegration::~LogindIntegration() = default;
 void LogindIntegration::logindServiceRegistered()
 {
     // get the current session
-    QDBusMessage message = QDBusMessage::createMethodCall(s_login1Service,
-                                                          s_login1Path,
-                                                          s_login1ManagerInterface,
-                                                          QStringLiteral("GetSessionByPID"));
-    message.setArguments(QVariantList() << (quint32) QCoreApplication::applicationPid());
+    QDBusMessage message = QDBusMessage::createMethodCall(s_login1Service, s_login1Path, s_login1ManagerInterface, QStringLiteral("GetSession"));
+    message.setArguments({QStringLiteral("auto")});
     QDBusPendingReply<QDBusObjectPath> session = m_bus.asyncCall(message);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(session, this);
 
@@ -122,10 +120,8 @@ void LogindIntegration::consolekitServiceRegistered()
     }
 
     // get the current session
-    QDBusMessage message = QDBusMessage::createMethodCall(s_consolekitService,
-                                                          s_consolekitPath,
-                                                          s_consolekitManagerInterface,
-                                                          QStringLiteral("GetCurrentSession"));
+    QDBusMessage message =
+        QDBusMessage::createMethodCall(s_consolekitService, s_consolekitPath, s_consolekitManagerInterface, QStringLiteral("GetCurrentSession"));
     QDBusPendingReply<QDBusObjectPath> session = m_bus.asyncCall(message);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(session, this);
 
@@ -139,47 +135,29 @@ void LogindIntegration::consolekitServiceRegistered()
 
 void LogindIntegration::commonServiceRegistered(QDBusPendingCallWatcher *watcher)
 {
-    connect(watcher, &QDBusPendingCallWatcher::finished, this,
-        [this](QDBusPendingCallWatcher *self) {
-            QDBusPendingReply<QDBusObjectPath> reply = *self;
-            self->deleteLater();
-            if (m_connected) {
-                return;
-            }
-            if (!reply.isValid()) {
-                qCDebug(KSCREENLOCKER) << "The session is not registered: "
-                                       << reply.error().message();
-                return;
-            }
-            m_sessionPath = reply.value().path();
-            qCDebug(KSCREENLOCKER) << "Session path:" << m_sessionPath;
-
-            // connections need to be done this way as the object exposes both method and signal
-            // with name "Lock"/"Unlock". Qt is not able to automatically handle this.
-            m_bus.connect(*m_service,
-                          m_sessionPath,
-                          *m_sessionInterface,
-                          QStringLiteral("Lock"),
-                          this,
-                          SIGNAL(requestLock()));
-            m_bus.connect(*m_service,
-                          m_sessionPath,
-                          *m_sessionInterface,
-                          QStringLiteral("Unlock"),
-                          this,
-                          SIGNAL(requestUnlock()));
-            m_connected = true;
-            emit connectedChanged();
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *self) {
+        QDBusPendingReply<QDBusObjectPath> reply = *self;
+        self->deleteLater();
+        if (m_connected) {
+            return;
         }
-    );
+        if (!reply.isValid()) {
+            qCDebug(KSCREENLOCKER) << "The session is not registered: " << reply.error().message();
+            return;
+        }
+        m_sessionPath = reply.value().path();
+        qCDebug(KSCREENLOCKER) << "Session path:" << m_sessionPath;
+
+        // connections need to be done this way as the object exposes both method and signal
+        // with name "Lock"/"Unlock". Qt is not able to automatically handle this.
+        m_bus.connect(*m_service, m_sessionPath, *m_sessionInterface, QStringLiteral("Lock"), this, SIGNAL(requestLock()));
+        m_bus.connect(*m_service, m_sessionPath, *m_sessionInterface, QStringLiteral("Unlock"), this, SIGNAL(requestUnlock()));
+        m_connected = true;
+        Q_EMIT connectedChanged();
+    });
 
     // connect to manager object's signals we need
-    m_bus.connect(*m_service,
-                  *m_path,
-                  *m_managerInterface,
-                  QStringLiteral("PrepareForSleep"),
-                  this,
-                  SIGNAL(prepareForSleep(bool)));
+    m_bus.connect(*m_service, *m_path, *m_managerInterface, QStringLiteral("PrepareForSleep"), this, SIGNAL(prepareForSleep(bool)));
 }
 
 void LogindIntegration::inhibit()
@@ -192,27 +170,20 @@ void LogindIntegration::inhibit()
         return;
     }
 
-    QDBusMessage message = QDBusMessage::createMethodCall(*m_service,
-                                                          *m_path,
-                                                          *m_managerInterface,
-                                                          QStringLiteral("Inhibit"));
-    message.setArguments(QVariantList({QStringLiteral("sleep"),
-                                       i18n("Screen Locker"),
-                                       i18n("Ensuring that the screen gets locked before going to sleep"),
-                                       QStringLiteral("delay")}));
+    QDBusMessage message = QDBusMessage::createMethodCall(*m_service, *m_path, *m_managerInterface, QStringLiteral("Inhibit"));
+    message.setArguments(QVariantList(
+        {QStringLiteral("sleep"), i18n("Screen Locker"), i18n("Ensuring that the screen gets locked before going to sleep"), QStringLiteral("delay")}));
     QDBusPendingReply<QDBusUnixFileDescriptor> reply = m_bus.asyncCall(message);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
-    connect(watcher, &QDBusPendingCallWatcher::finished, this,
-        [this](QDBusPendingCallWatcher *self) {
-            QDBusPendingReply<QDBusUnixFileDescriptor> reply = *self;
-            self->deleteLater();
-            if (!reply.isValid()) {
-                return;
-            }
-            reply.value().swap(m_inhibitFileDescriptor);
-            emit inhibited();
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *self) {
+        QDBusPendingReply<QDBusUnixFileDescriptor> reply = *self;
+        self->deleteLater();
+        if (!reply.isValid()) {
+            return;
         }
-    );
+        reply.value().swap(m_inhibitFileDescriptor);
+        Q_EMIT inhibited();
+    });
 }
 
 void LogindIntegration::uninhibit()
@@ -234,10 +205,7 @@ void LogindIntegration::setLocked(bool locked)
         return;
     }
 
-    QDBusMessage message = QDBusMessage::createMethodCall(*m_service,
-                                                          m_sessionPath,
-                                                          *m_sessionInterface,
-                                                          QStringLiteral("SetLockedHint"));
+    QDBusMessage message = QDBusMessage::createMethodCall(*m_service, m_sessionPath, *m_sessionInterface, QStringLiteral("SetLockedHint"));
     message.setArguments({locked});
     m_bus.call(message, QDBus::NoBlock);
 }
@@ -248,8 +216,7 @@ bool LogindIntegration::isLocked() const
         return false;
     }
 
-    QDBusMessage message = QDBusMessage::createMethodCall(*m_service, m_sessionPath, s_propertyInterface,
-                                                          QStringLiteral("Get"));
+    QDBusMessage message = QDBusMessage::createMethodCall(*m_service, m_sessionPath, s_propertyInterface, QStringLiteral("Get"));
     message.setArguments({*m_sessionInterface, QStringLiteral("LockedHint")});
     QDBusReply<QDBusVariant> reply = m_bus.call(message);
     if (reply.isValid()) {
